==> haskell-logging-facade-0.3.1-325-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-FbdERCkT6sqBUtHbJgsXnb
key:                  logging-facade-0.3.1-FbdERCkT6sqBUtHbJgsXnb
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  16c415dfdabb87696ba55a09088fe5a2
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.4.8/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/logging-facade-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-FbdERCkT6sqBUtHbJgsXnb
depends:
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.1-327-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-K8b26F3IoG411LD9QbhOdY
key:                  logging-facade-0.3.1-K8b26F3IoG411LD9QbhOdY
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  81406d6df916013ecf93601e25f8c55e
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.4.8/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/logging-facade-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-K8b26F3IoG411LD9QbhOdY
depends:
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
